@@ -346,7 +346,6 @@ void KFormatTest::formatRelativeDate()
     KFormat format(QLocale::c());
 
     QDate testDate = QDate::currentDate();
-
     QCOMPARE(format.formatRelativeDate(testDate, QLocale::LongFormat), QStringLiteral("Today"));
     QCOMPARE(format.formatRelativeDate(testDate, QLocale::ShortFormat), QStringLiteral("Today"));
     QCOMPARE(format.formatRelativeDate(testDate, QLocale::NarrowFormat), QStringLiteral("Today"));
@@ -393,8 +392,13 @@ void KFormatTest::formatRelativeDate()
     }
 
     QDateTime testDateTime = now.addSecs(-3600);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 11, 0)
+    QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat),
+             QStringLiteral("Today at %1").arg(testDateTime.toString(QStringLiteral("hh:mm"))));
+#else
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat),
              QStringLiteral("Today at %1").arg(testDateTime.toString(QStringLiteral("hh:mm:ss"))));
+#endif
 
     // 1 second ago
     now = QDateTime::currentDateTime();
@@ -402,15 +406,18 @@ void KFormatTest::formatRelativeDate()
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), QStringLiteral("Just now"));
 
     // 1 second ahead
+    now = QDateTime::currentDateTime();
     testDateTime = now.addSecs(1);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), QStringLiteral("Now"));
 
     // 5 minutes ago
+    now = QDateTime::currentDateTime();
     testDateTime = now.addSecs(-300);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), QStringLiteral("5 minute(s) ago"));
 
-    // 5 minutes ahead
-    testDateTime = now.addSecs(300);
+    // 5 minutes ahead, plus some seconds to be not that flacky during testing
+    now = QDateTime::currentDateTime();
+    testDateTime = now.addSecs(310);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), "In 5 minute(s)"_L1);
 
     testDateTime = QDateTime(QDate::currentDate().addDays(8), QTime(3, 0, 0));
@@ -433,10 +440,9 @@ void KFormatTest::formatRelativeDate()
     QCOMPARE(formatFrench.formatRelativeDateTime(testDateTime, QLocale::LongFormat), QStringLiteral("Dimanche 3 octobre 2021 at 05:33"));
 
     // narrow format
-    now = QDateTime::currentDateTime();
-    testDateTime = now.addSecs(-1);
+    testDateTime = QDateTime::currentDateTime().addSecs(-1);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::NarrowFormat), "Just now"_L1);
-    testDateTime = now.addSecs(1);
+    testDateTime = QDateTime::currentDateTime().addSecs(1);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::NarrowFormat), "Now"_L1);
 
     testDateTime = QDateTime::currentDateTime().addSecs(-330);
